installed_frameworks

Function installed_frameworks 

pub fn installed_frameworks() -> Vec<&'static dyn FrameworkAdapter>
Get all frameworks that are installed on the system.

Uses the is_installed() method on each adapter to determine if the framework’s config directory exists or CLI tool is available.