InitOptions

Struct InitOptions 

pub struct InitOptions {
    pub frameworks: Vec<String>,
    pub local: bool,
    pub settings_local: bool,
    pub otel: bool,
    pub otel_port: u16,
    pub remove_otel: bool,
    pub db_only: bool,
    pub hooks_only: bool,
}
Options for hook initialization and activation.

This struct contains all the options needed to initialize mi6 programmatically.

Fields

frameworks: Vec<String>

Frameworks to install hooks for (e.g., ["claude", "gemini", "codex"]). If empty, auto-detection will be used.

local: bool

Install hooks to project config instead of global.

settings_local: bool

Install hooks to project local config (not committed to git).

otel: bool

Configure OpenTelemetry env vars for token tracking.

otel_port: u16

Port for OTel server.

remove_otel: bool

Remove OTel configuration (disables token tracking).

db_only: bool

Only initialize database, skip hook installation (high-level API only).

hooks_only: bool

Only install hooks, skip database initialization (high-level API only).

Implementations

Source

impl InitOptions

pub fn new() -> Self

Create new InitOptions with default values.

pub fn for_framework(framework: impl Into<String>) -> Self

Create InitOptions for a single framework.

pub fn for_frameworks(frameworks: Vec<String>) -> Self

Create InitOptions for multiple frameworks.

pub fn get_frameworks(&self) -> Vec<String>

Get the list of frameworks to initialize.

pub fn local(self, local: bool) -> Self

Set install location to project config instead of global.

pub fn settings_local(self, settings_local: bool) -> Self

Set install location to project local config (not committed to git).

pub fn otel(self, otel: bool) -> Self

Enable OpenTelemetry configuration for token tracking.

pub fn otel_port(self, port: u16) -> Self

Set the port for OTel server.

pub fn remove_otel(self, remove: bool) -> Self

Remove OTel configuration (disables token tracking).

pub fn db_only(self, db_only: bool) -> Self

Only initialize database, skip hook installation.

pub fn hooks_only(self, hooks_only: bool) -> Self

Only install hooks, skip database initialization.