pub struct InstallHooksResult {
pub commands_run: Vec<String>,
}Expand description
Result of hook installation.
Contains information about what was done during installation, including any shell commands that were executed.
Fields
commands_run: Vec<String>Shell commands that were executed during installation. Each string is the full command that was run.