pub struct CodexSessionParser { /* private fields */ }Expand description
Parser for Codex CLI session JSONL files.
Implementations
Sourceimpl CodexSessionParser
impl CodexSessionParser
Sourcepub fn new(machine_id: impl Into<String>) -> Self
pub fn new(machine_id: impl Into<String>) -> Self
Create a new parser with the given machine ID.
Sourcepub fn parse_incremental(
&self,
path: &Path,
session_id: &str,
start_position: &FilePosition,
) -> Result<ParseResult, TranscriptError>
pub fn parse_incremental( &self, path: &Path, session_id: &str, start_position: &FilePosition, ) -> Result<ParseResult, TranscriptError>
Parse new entries from a session file starting at the given position.
Returns events, updated position, and dedup keys seen.
Sourcepub fn parse_full(
&self,
path: &Path,
session_id: &str,
) -> Result<ParseResult, TranscriptError>
pub fn parse_full( &self, path: &Path, session_id: &str, ) -> Result<ParseResult, TranscriptError>
Parse entire session file from the beginning.