pub fn find_framework_process() -> Option<FrameworkProcessInfo>Expand description
Walk up the process tree to find the framework process.
Looks for Claude, Codex, Gemini, Cursor, or other supported frameworks in the process ancestry.
Returns None if we can’t find a framework process in the ancestry.