pub fn enable(options: InitOptions) -> Result<EnableResult, EnableError>Expand description
Enable mi6 hooks for AI coding frameworks.
This is the main entry point for programmatic enabling. It:
- Resolves which frameworks to enable (auto-detect or explicit)
- Installs hooks for each framework
Note: Port conflict checking should be done by the caller using
mi6_otel_server::is_server_running() and mi6_otel_server::find_available_port()
before calling this function if OTel is enabled.
Example
ⓘ
use mi6_core::{InitOptions, enable};
let result = enable(InitOptions::for_framework("claude").otel(true))?;